:py:mod:`piel.openlane_v2`
==========================

.. py:module:: piel.openlane_v2


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.openlane_v2.run_openlane



.. py:function:: run_openlane(design_directory: str = '.', configuration: dict = test_spm_open_lane_configuration)


